;/*******************************************************************************
;* Copyright (C) 2013 Spansion LLC. All Rights Reserved. 
;*
;* This software is owned and published by: 
;* Spansion LLC, 915 DeGuigne Dr. Sunnyvale, CA  94088-3453 ("Spansion").
;*
;* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND 
;* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
;*
;* This software contains source code for use with Spansion 
;* components. This software is licensed by Spansion to be adapted only 
;* for use in systems utilizing Spansion components. Spansion shall not be 
;* responsible for misuse or illegal use of this software for devices not 
;* supported herein.  Spansion is providing this software "AS IS" and will 
;* not be responsible for issues arising from incorrect user implementation 
;* of the software.  
;*
;* SPANSION MAKES NO WARRANTY, EXPRESS OR IMPLIED, ARISING BY LAW OR OTHERWISE,
;* REGARDING THE SOFTWARE (INCLUDING ANY ACOOMPANYING WRITTEN MATERIALS), 
;* ITS PERFORMANCE OR SUITABILITY FOR YOUR INTENDED USE, INCLUDING, 
;* WITHOUT LIMITATION, THE IMPLIED WARRANTY OF MERCHANTABILITY, THE IMPLIED 
;* WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE OR USE, AND THE IMPLIED 
;* WARRANTY OF NONINFRINGEMENT.  
;* SPANSION SHALL HAVE NO LIABILITY (WHETHER IN CONTRACT, WARRANTY, TORT, 
;* NEGLIGENCE OR OTHERWISE) FOR ANY DAMAGES WHATSOEVER (INCLUDING, WITHOUT 
;* LIMITATION, DAMAGES FOR LOSS OF BUSINESS PROFITS, BUSINESS INTERRUPTION, 
;* LOSS OF BUSINESS INFORMATION, OR OTHER PECUNIARY LOSS) ARISING FROM USE OR 
;* INABILITY TO USE THE SOFTWARE, INCLUDING, WITHOUT LIMITATION, ANY DIRECT, 
;* INDIRECT, INCIDENTAL, SPECIAL OR CONSEQUENTIAL DAMAGES OR LOSS OF DATA, 
;* SAVINGS OR PROFITS, 
;* EVEN IF SPANSION HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. 
;* YOU ASSUME ALL RESPONSIBILITIES FOR SELECTION OF THE SOFTWARE TO ACHIEVE YOUR
;* INTENDED RESULTS, AND FOR THE INSTALLATION OF, USE OF, AND RESULTS OBTAINED 
;* FROM, THE SOFTWARE.  
;*
;* This software may be replicated in part or whole for the licensed use, 
;* with the restriction that this Disclaimer and Copyright notice must be 
;* included with each copy of this software, whether used in part or whole, 
;* at all times.  
;*/

;/************************************************************************/
;/*  Startup for ARM                                                     */
;/*  Version     V1.2                                                    */
;/*  Date        2014-01-20                                              */
;/*  Target-mcu  S6E1A1                                                  */
;/************************************************************************/

; Stack Configuration
;  Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>

Stack_Size      EQU     0x00000200

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; Heap Configuration
;  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>

Heap_Size       EQU     0x00000000

                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors
                EXPORT  __Vectors_End
                EXPORT  __Vectors_Size

__Vectors       DCD     __initial_sp              ; Top of Stack
                DCD     Reset_Handler             ; Reset Handler
                DCD     NMI_Handler               ; NMI Handler
                DCD     HardFault_Handler         ; Hard Fault Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     SVC_Handler               ; SVCall Handler
                DCD     0                         ; Reserved
                DCD     0                         ; Reserved
                DCD     PendSV_Handler            ; PendSV Handler
                DCD     SysTick_Handler           ; SysTick Handler

                DCD     CSV_IRQHandler            ; 0: Clock Super Visor
                DCD     SWDT_IRQHandler           ; 1: Software Watchdog Timer
                DCD     LVD_IRQHandler            ; 2: Low Voltage Detector
                DCD     MFT_WFG_DTIF_IRQHandler   ; 3: Wave Form Generator / DTIF
                DCD     EXINT0_7_IRQHandler       ; 4: External Interrupt Request ch.0 to ch.7
                DCD     DummyIRQHandler           ; 5: Reserved
                DCD     DT_QDU_IRQHandler         ; 6: Dual Timer / Quad Decoder
                DCD     MFS0_RX_IRQHandler        ; 7: MultiFunction Serial ch.0 
                DCD     MFS0_TX_IRQHandler        ; 8: MultiFunction Serial ch.0 
                DCD     MFS1_RX_IRQHandler        ; 9: MultiFunction Serial ch.1
                DCD     MFS1_TX_IRQHandler        ; 10: MultiFunction Serial ch.1
                DCD     DummyIRQHandler           ; 11: Reserved
                DCD     DummyIRQHandler           ; 12: Reserved
                DCD     MFS3_RX_IRQHandler        ; 13: MultiFunction Serial ch.3
                DCD     MFS3_TX_IRQHandler        ; 14: MultiFunction Serial ch.3
                DCD     DummyIRQHandler           ; 15: Reserved
                DCD     DummyIRQHandler           ; 16: Reserved
                DCD     DummyIRQHandler           ; 17: Reserved
                DCD     DummyIRQHandler           ; 18: Reserved
                DCD     DMAC0_IRQHandler          ; 19: DMA ch.0
                DCD     DMAC1_IRQHandler          ; 20: DMA ch.1
                DCD     DummyIRQHandler           ; 21: Reserved
                DCD     DummyIRQHandler           ; 22: Reserved
                DCD     PPG_IRQHandler            ; 23: PPG
                DCD     TIM_IRQHandler            ; 24: OSC / PLL / Watch Counter / RTC
                DCD     ADC0_IRQHandler           ; 25: ADC0
                DCD     DummyIRQHandler           ; 26: Reserved
                DCD     DummyIRQHandler           ; 27: Reserved
                DCD     MFT_FRT_IRQHandler        ; 28: Free-run Timer
                DCD     MFT_IPC_IRQHandler        ; 29: Input Capture
                DCD     MFT_OPC_IRQHandler        ; 30: Output Compare
                DCD     BT0_3_FLASH_IRQHandler    ; 31: Base Timer ch.0 to ch.3 / Flash
                
__Vectors_End

__Vectors_Size 	EQU 	__Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY


; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)

NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  CSV_IRQHandler	             [WEAK]
                EXPORT  SWDT_IRQHandler              [WEAK]
                EXPORT  LVD_IRQHandler               [WEAK]
                EXPORT  MFT_WFG_DTIF_IRQHandler      [WEAK]
                EXPORT  EXINT0_7_IRQHandler          [WEAK]
                EXPORT  DT_QDU_IRQHandler            [WEAK]
                EXPORT  MFS0_RX_IRQHandler           [WEAK]
                EXPORT  MFS0_TX_IRQHandler           [WEAK]
                EXPORT  MFS1_RX_IRQHandler           [WEAK]
                EXPORT  MFS1_TX_IRQHandler           [WEAK]
                EXPORT  MFS3_RX_IRQHandler           [WEAK]
                EXPORT  MFS3_TX_IRQHandler           [WEAK]
                EXPORT  DMAC0_IRQHandler             [WEAK]
                EXPORT  DMAC1_IRQHandler             [WEAK]
                EXPORT  PPG_IRQHandler               [WEAK]
                EXPORT  TIM_IRQHandler               [WEAK]
                EXPORT  ADC0_IRQHandler              [WEAK]
                EXPORT  MFT_FRT_IRQHandler           [WEAK]
                EXPORT  MFT_IPC_IRQHandler           [WEAK]
                EXPORT  MFT_OPC_IRQHandler           [WEAK]
                EXPORT  BT0_3_FLASH_IRQHandler       [WEAK]


CSV_IRQHandler	             
SWDT_IRQHandler              
LVD_IRQHandler               
MFT_WFG_DTIF_IRQHandler     
EXINT0_7_IRQHandler          
DT_QDU_IRQHandler            
MFS0_RX_IRQHandler           
MFS0_TX_IRQHandler          
MFS1_RX_IRQHandler           
MFS1_TX_IRQHandler           
MFS3_RX_IRQHandler           
MFS3_TX_IRQHandler           
DMAC0_IRQHandler            
DMAC1_IRQHandler            
PPG_IRQHandler               
TIM_IRQHandler
ADC0_IRQHandler
MFT_FRT_IRQHandler           
MFT_IPC_IRQHandler           
MFT_OPC_IRQHandler           
BT0_3_FLASH_IRQHandler       
DummyIRQHandler

                B       .

                ENDP


                ALIGN


; User Initial Stack & Heap

                IF      :DEF:__MICROLIB
                
                EXPORT  __initial_sp
                EXPORT  __heap_base
                EXPORT  __heap_limit
                
                ELSE
                
                IMPORT  __use_two_region_memory
                EXPORT  __user_initial_stackheap
__user_initial_stackheap

                LDR     R0, =  Heap_Mem
                LDR     R1, =(Stack_Mem + Stack_Size)
                LDR     R2, = (Heap_Mem +  Heap_Size)
                LDR     R3, = Stack_Mem
                BX      LR

                ALIGN

                ENDIF


                END
